@@ -42,7 +42,7 @@ def node_json():
                 "args": [
                     {
                         "name": "lhs",
-                        "value": "item1",
+                        "value": "item1.child1",
                         "payloadElement": True
                     },
                     {
@@ -105,7 +105,9 @@ def node_json():
 @pytest.fixture
 def payload_one():
     payload = {
-        'item1': 1,
+        'item1': {
+            'child1': 1
+        },
         'item2': 2,
         'item3': '3',
         'item4': 4,
@@ -122,7 +124,9 @@ def payload_one():
 @pytest.fixture
 def payload_two():
     payload = {
-        'item1': 1,
+        'item1': {
+            'child1': 1
+        },
         'item2': 0,
         'item3': '3',
         'item4': 4,
